@@ -20,7 +20,7 @@ class CXWaylandServer {
     bool start();
 
     // called on ready
-    int  ready(Hyprutils::OS::CFileDescriptor fd, uint32_t mask);
+    int  ready(int fd, uint32_t mask);
 
     void die();
 
@@ -34,8 +34,6 @@ class CXWaylandServer {
     bool                                          tryOpenSockets();
     void                                          runXWayland(Hyprutils::OS::CFileDescriptor& notifyFD);
 
-    pid_t                                         serverPID = 0;
-
     std::string                                   displayName;
     int                                           display = -1;
     std::array<Hyprutils::OS::CFileDescriptor, 2> xFDs;
